import re


class Cleaner(object):
    @staticmethod
    def clean(string):
        if string != '#':
            result = "_".join(string.split())
            result = re.sub("[^A-za-z0-9]", "", result)
            match = re.search("^([0-9]+)(.*)", result)
            if match:
                result = "_" + result

            result = result.lower()
            return result
        else:
            return '#'


class Convert(object):

    @staticmethod
    def str_type(string):
        result=(None, None, None)
        regex_list={
            'none_big_formal'           :'^((?:[A-Z])(?:[a-z|0-9]?)+)+$',         # AaaaAaaa
            'none_little_formal'        :'^([a-z]+)((?:[A-Z])(?:[a-z|0-9]?)+)+$', # aaaaAaaa
            'underline_little_unformal' :'^(?:[a-z])(_?(?:[a-z|0-9])+)+$',        # aaaa_aaaa
            'underline_little_formal'   :'^(?:[a-z])((_[A-Z])?(?:[a-z|0-9])*)+$', # aaaa_Aaaa
            'underline_big_formal'      :'^(?:[A-Z])((_[A-Z])?(?:[a-z|0-9])*)+$', # Aaaa_Aaaa
            'hyphen_little_unformal'    :'^(?:[a-z])(-?(?:[a-z|0-9])+)+$',        # aaaa-aaaa
            'hyphen_little_formal'      :'^(?:[a-z])((-[A-Z])?(?:[a-z|0-9])*)+$', # aaaa-Aaaa
            'hyphen_big_formal'         :'^(?:[A-Z])((-[A-Z])?(?:[a-z|0-9])*)+$', # Aaaa-Aaaa
            'space_little_unformal'     :'^(?:[a-z])( ?(?:[a-z|0-9])+)+$',        # aaaa aaaa
            'space_little_formal'       :'^(?:[a-z])(( [A-Z])?(?:[a-z|0-9])*)+$', # aaaa Aaaa
            'space_big_formal'          :'^(?:[A-Z])(( [A-Z])?(?:[a-z|0-9])*)+$', # Aaaa Aaaa

        }

        for name, regex in regex_list.items():
            match = re.search(regex,string)
            if match:
                result = tuple(name.split('_'))
        return result
    @staticmethod
    def none_to_underline(string):
        filter1 = re.compile(r'(.)([A-Z][a-z]+)')
        filter2 = re.compile(r'([a-z0-9])([A-Z])')

        return filter2.sub(r'\1_\2', filter1.sub(r'\1_\2', string))

    @staticmethod
    def hyphen_to_underline(string):
        return string.replace('-', '_')

    @staticmethod
    def space_to_underline(string):
        return string.replace(' ', '_')

    @staticmethod
    def formal_to_unformal(string):
        return string[0]+string[1:].lower()

    @staticmethod
    def big_to_little(string):
        return string[0].lower()+string[1:]




from termcolor import colored


class Title(object):
    """
    this class contains a helper function which you can configure every single instance differently
    """

    def __init__(self, label='', length=80, color='blue', design_char='#'):
        self.configure(label, length, color, design_char)

    def configure(self, label=None, length=None, color=None, design_char=None):
        if length is not None:
            if length < 0 or length > 80:
                raise Exception("Length must greater than 0 and smaller than 80")
            self.length = length
        if label is not None:
            if len(label) > self.length-2:
                raise Exception("label can not be greater than (length - 2) ")
            self.label = label
        if color is not None:
            if color not in ['grey', 'red', 'green', 'yellow', 'blue', 'magenta', 'cyan', 'white']:
                raise Exception("color can be 'grey', 'red', 'green', 'yellow', 'blue', 'magenta', 'cyan' or 'white'")
            self.color = color
        if design_char is not None:
            if len(design_char) != 1:
                raise Exception("Design char length must be 1")
            self.design_char = design_char
        return self

    def write(self, label=None):
        """
        helper
        hashtag label function
        this function is print label in center of print(length*"#")
        label:  Message what you say
        length: Column number

        """
        if label is not None:
            self.configure(label=label)

        if self.length < 2:
            raise Exception("length must greater than 2")
        len_of_label = len(self.label)
        if len_of_label == 0:
            left_space = self.length/2
            rigth_space = self.length/2
        elif len_of_label < 0 or len_of_label > self.length - 2:
            raise Exception("Out of range")
        elif len_of_label % 2 == 0:
            left_space = (self.length - len_of_label) / 2
            if self.length % 2 == 0:
                rigth_space = left_space
            else:
                rigth_space = left_space+1
        elif len_of_label % 2 == 1:
            left_space = (self.length - len_of_label) / 2
            if self.length % 2 == 0:
                rigth_space = left_space+1
            else:
                rigth_space = left_space
        print(colored(self.length*self.design_char, self.color))
        print(colored(self.design_char, self.color), end='')
        print((int(left_space)-1)*" ", end='')
        print(colored(self.label.upper(), self.color), end='')
        print((int(rigth_space)-1)*" ", end='')
        print(colored(self.design_char, self.color))
        print(colored(self.length*self.design_char, self.color))









import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="alyssum",
    version="0.0.4",
    author="Erdem Aybek",
    author_email="eaybek@gmail.com",
    description="A small helper package for personal needs",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/eaybek/alyssum",
    packages=setuptools.find_packages(),
    classifiers=[
        "Development Status :: 1 - Planning",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'termcolor',
        're',
    ],
)
